BollingerBandsOverlayPainter class

Painter para renderizar overlay Bollinger Bands.

Inheritance

Constructors

BollingerBandsOverlayPainter({required ChartViewport viewport, required List<BarPrimitive> bars, required ChartTheme theme, required List<BollingerBandValue> values, required BollingerBandsIndicator indicator})

Properties

bars List<BarPrimitive>
Full bar data buffer.
finalinherited
bearishPaint Paint
no setterinherited
bearishStrokePaint Paint
no setterinherited
bullishPaint Paint
no setterinherited
bullishStrokePaint Paint
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
indicator BollingerBandsIndicator
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
showDebugGrid bool
If true, draws a debug overlay grid.
finalinherited
theme ChartTheme
Visual theme.
finalinherited
values List<BollingerBandValue>
final
viewport ChartViewport
Current viewport state.
finalinherited
visibleBars List<BarPrimitive>
no setterinherited
visibleIndices → (int, int)
no setterinherited
wickPaintBearish Paint
no setterinherited
wickPaintBullish Paint
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
createConverter(Size size) ChartScaleConverter
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
inherited
paintChart(Canvas canvas, Size size) → void
override
paintOverlay(Canvas canvas, Size size) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant BaseChartPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant BollingerBandsOverlayPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited