DrawingStyle class

Define o estilo visual de um objeto de desenho.

Annotations
  • @freezed

Constructors

DrawingStyle({@DrawingColorConverter() @Default.new(Color(0xFF2196F3)) Color lineColor, @Default.new(1.5) double lineWidth, List<double>? dashPattern})
const
factory
DrawingStyle.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $DrawingStyleCopyWith<DrawingStyle>
Create a copy of DrawingStyle with the given fields replaced by the non-null parameter values.
no setterinherited
dashPattern List<double>?
Padrão de tracejado (ex: 5, 5 para linha tracejada)
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
lineColor Color
Cor da linha
no setterinherited
lineWidth double
Espessura da linha
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this DrawingStyle to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited