MACDIndicator class

Define o modelo de dados para o indicador MACD (Moving Average Convergence Divergence).

Annotations
  • @freezed

Constructors

MACDIndicator({@Default.new(12) int fastPeriod, @Default.new(26) int slowPeriod, @Default.new(9) int signalPeriod, required List<MACDValue> values, @MACDColorConverter() @Default.new(Color(0xFF2196F3)) Color macdLineColor, @MACDColorConverter() @Default.new(Color(0xFFFF9800)) Color signalLineColor, @MACDColorConverter() @Default.new(Color(0xFF4CAF50)) Color histogramPositiveColor, @MACDColorConverter() @Default.new(Color(0xFFF44336)) Color histogramNegativeColor, @Default.new(1.5) double lineWidth, required bool visible})
const
factory
MACDIndicator.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $MACDIndicatorCopyWith<MACDIndicator>
Create a copy of MACDIndicator with the given fields replaced by the non-null parameter values.
no setterinherited
fastPeriod int
Período rápido (EMA curta) - padrão 12
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
histogramNegativeColor Color
Cor do histograma negativo (MACD < Signal).
no setterinherited
histogramPositiveColor Color
Cor do histograma positivo (MACD > Signal).
no setterinherited
lineWidth double
Espessura das linhas.
no setterinherited
macdLineColor Color
Cor da linha MACD.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signalLineColor Color
Cor da linha Signal.
no setterinherited
signalPeriod int
Período da linha Signal (EMA do MACD) - padrão 9
no setterinherited
slowPeriod int
Período lento (EMA longa) - padrão 26
no setterinherited
values List<MACDValue>
Os valores calculados do MACD alinhados com a array de barras no tempo. Zonas sem cálculo suficiente no início estarão preenchidas com NaN.
no setterinherited
visible bool
Define se o indicador está visível.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this MACDIndicator to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited