BollingerBandsCalculator class
Motor para calcular Bollinger Bands.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
calculate(
List< BarPrimitive> bars, int period, double stdDev) → List<BollingerBandValue> - Calcula Bollinger Bands para todas as barras (O(N)).
-
calculateIncremental(
BarPrimitive newBar, List< BarPrimitive> previousBars, int period, double stdDev, BollingerBandValue? previousValue) → BollingerBandValue? - Calcula incrementalmente para um novo bar (O(1)).