EMACalculator class
Executa a rotina matemática de Média Móvel Exponencial (EMA).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
calculate(
List< BarPrimitive> bars, int period) → List<double> - Calcula EMA para lista completa de barras on-the-fly.
-
calculateIncremental(
List< BarPrimitive> bars, int period, List<double> previousValues) → double? - Versão otimizada (incremental) para atualizações restritas a ticks no final (websockets). Caso seja null ou não consiga aproveitar array passada, calcula puro on-demand do chunk final.